from pyramid.config import Configurator
from pyramid.i18n import TranslationStringFactory

from ringo.lib.sql.db import setup_db_session, setup_db_engine
from ringo.model import Base
from ringo.lib.i18n import translators


def main(global_config, **settings):
    """ This function returns a Pyramid WSGI application."""
    engine = setup_db_engine(settings)
    setup_db_session(engine)
    Base.metadata.bind = engine
    config = Configurator(settings=settings)
    config.include('ringo.lib.sql.db.setup_session_on_request')
    config.include('ringo.lib.cache.setup_cache')
    config.include('ecimporter')
    config.scan()
    config.commit()
    return config.make_wsgi_app()


def includeme(config):
    # Now configure the application and optionally overwrite previously
    translators.append(TranslationStringFactory('ecimporter'))
    config.add_translation_dirs('ecimporter:locale/')
    config.add_static_view('ecimporter-static', path='ecimporter:static',
                           cache_max_age=3600)
    config.add_route('import', '/')
    config.add_route('course', '/course')
